@@ -5,12 +5,14 @@ import enum
 import typing
 
 import jsii
-import jsii.compat
 import publication
+import typing_extensions
 
 import aws_cdk.cloud_assembly_schema._jsii
 
-__jsii_assembly__ = jsii.JSIIAssembly.load("@aws-cdk/cx-api", "1.49.0", __name__[0:-6], "cx-api@1.49.0.jsii.tgz")
+__jsii_assembly__ = jsii.JSIIAssembly.load(
+    "@aws-cdk/cx-api", "1.85.0", __name__[0:-6], "cx-api@1.85.0.jsii.tgz"
+)
 
 __all__ = [
     "__jsii_assembly__",
